#
# spec file for package ssdp-responder
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2018-2023, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ssdp-responder
Version:        2.0
Release:        1.3
Summary:        SSDP responder for Linux
License:        ISC
Group:          Productivity/Networking/Other
URL:            https://github.com/troglobit/ssdp-responder
#Git-Clone:     https://github.com/troglobit/ssdp-responder.git
Source:         https://github.com/troglobit/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch0:         harden_ssdpd.service.patch
BuildRequires:  autoconf
BuildRequires:  automake
%{?systemd_requires}

%description
ssdpd is a stand-alone daemon that implements the Simple Service
Discovery Protocol (SSDP) for use by networked Linux devices that
want to announce themselves to systems running Windows. ssdpd has a
built-in web server for serving the UPnP XML description which
Windows uses to present the icon when an InternetGatewayDevice is
announced.

%prep
%autosetup -p1

%build
autoreconf -fiv
%configure --with-systemd=%{_unitdir}
%make_build

%install
%make_install
rm -Rv %{buildroot}/%{_datadir}/doc

%preun
%service_del_preun ssdpd.service

%postun
%service_del_postun ssdpd.service

%pre
%service_add_pre ssdpd.service

%post
%service_add_post ssdpd.service

%files
%doc README.md
%license LICENSE
%{_bindir}/ssdp-scan
%{_sbindir}/ssdpd
%{_mandir}/man1/ssdp-scan.1%{?ext_man}
%{_mandir}/man8/ssdpd.8%{?ext_man}
%{_unitdir}/ssdpd.service

%changelog
* Mon Feb 27 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 2.0
  Changes
  Add suport for
  * -c NAME to override ssdpd UUID cache file.
  * -d URL to override the UPnP description URL, a single %%s is
    supported to be replaced with the interface address.
  * -m NAME to override the manufacturer in the default
    description.xml.
  * -M URL to override the manufacturerURL in the default
    description.xml.
  * -p URL to override the presentationURL in the default
    description.xml, a single %%s is supported.
  * -P FILE to override the default PID file location default
    description.xml, a single %%s is supported.
  * -u UUID to use a custom UUID, useful when the built-in micro
    HTTP server is disabled.
  * -w to disable built-in micro HTTP server, useful when other,
    more capable, web servers are available. Make sure to have the
    alternate web server running on port 1901 to serve the file
    /description.xml, see also -d URL above, which details the
    location of the UPnP description URL.
  * Increased debug messages in ssdp_init(), for troubleshooting.
  * dropping root privileges after initial setup. The used ssdp
    is searched for first, with fallback to nobody.
  * Add support for an initial retry interval at startup, in
    case ssdpd is started before any interface has been configured.
    Configurable retry count using -R NUM command line option.
  * Add support for an IP address monitor using Linux netlink
    interfaces coming and going at runtime. Meaning, -R NUM is
    unused on Linux. For this to work, ssdpd must start as root or
    have CAP_NET_RAW.
  Fixes
  * Fix #11: periodic busy loop causing intermittent 100%% CPU load.
  * Fix invalid <UDN>uuid:uuid:...</UDN> in description.xml.
  * Add Date: and Server: to HTTP header in micro HTTP server.
  * Add support for HTTP HEAD requests to micro HTTP server.
  * Handle case when /etc/os-release does not have VERSION_ID fall
    back to use VERSION_CODENAME.
  * Don't overwrite CPPFLAGS from the command line.
  * Portability fix to utimensat() replacement function.
* Mon Oct 31 2022 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.9:
  * Add testing command line options to sscp-scan
  * Fix TOCTOU issue with caching of UUID
- includes changes form 1.8:
  * improvements to UUID cache directory handling
  * Fix avahi-daemon (mDNS) conflict
* Tue Nov 23 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_ssdpd.service.patch
* Wed Jun 10 2020 Martin Hauke <mardnh@gmx.de>
- Package systemd service file
- Update to version 1.7
  * Use /etc/os-release as base for SSDP server string,
    distribution release information is primarily stored in this
    file, some Linux systems still use /etc/lsb-release, on real
    UNIX systems we can use uname(1)
  * Update ssdpd(8) man page
- Update to version 1.6
  * Fix CVE-2019-14323
  * Refactor socket handling, enable SO_REUSEADDR + SO_REUSEPORT
  * Change default behavior, must now use -n to run in foreground
  * Add ssdp-scan tool, similar to mdns-scan
  * Add systemd unit file
* Sun Jul 29 2018 jengelh@inai.de
- Fix write style of description.
* Mon Jun 18 2018 mardnh@gmx.de
- Initial package, version 1.5
